<img src="/tf/docs/images/tf-small.png" align="left"/>

# Text-Fabric

[![SWH](https://archive.softwareheritage.org/badge/origin/https://github.com/annotation/text-fabric/)](https://archive.softwareheritage.org/browse/origin/https://github.com/annotation/text-fabric/)

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1008899.svg)](https://doi.org/10.5281/zenodo.592193)

[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/2592/badge)](https://bestpractices.coreinfrastructure.org/projects/2592)
[![Join the chat](https://badges.gitter.im/annotation/text-fabric.svg)](https://gitter.im/annotation/text-fabric?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

---

All about Text-Fabric is in the
[docs](https://annotation.github.io/text-fabric/tf).

Want to contribute?
Start with the [contribution notes](codestyle/contributing.md).

---

**This repository is being archived continuously by the 
[Software Heritage Archive](https://archive.softwareheritage.org).
If you want to cite snippets of the code of this repository, the Software Archive
offers an easy and elegant way to do so.
As an example, here I quote the 
[*stitching* algorithm](https://archive.softwareheritage.org/swh:1:cnt:6169c074089ddc8a0e048cb67e1fec57857ef54d;lines=3224-3270/),
by means of which Text-Fabric Search collects the solutions of a
[search template](https://annotation.github.io/text-fabric/tf/about/use.html).
The quote refers directly to specific lines of code, deeply buried in
a Python file within a particular version of Text-Fabric.**
